==> huaweicloudsdkeihealth-3.1.138-py2.py3-none-any.whl: huaweicloudsdkeihealth/v1/model/show_vendor_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowVendorResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'logo': 'str',
        'name': 'str'
    }

    attribute_map = {
        'logo': 'logo',
        'name': 'name'
    }

    def __init__(self, logo=None, name=None):
        """ShowVendorResponse

        The model defined in huaweicloud sdk

        :param logo: 商标Base64
        :type logo: str
        :param name: 名称
        :type name: str
        """
        
        super(ShowVendorResponse, self).__init__()

        self._logo = None
        self._name = None
        self.discriminator = None

        if logo is not None:
            self.logo = logo
        if name is not None:
            self.name = name

    @property
    def logo(self):
        """Gets the logo of this ShowVendorResponse.

        商标Base64

        :return: The logo of this ShowVendorResponse.
        :rtype: str
        """
        return self._logo

    @logo.setter
    def logo(self, logo):
        """Sets the logo of this ShowVendorResponse.

        商标Base64

        :param logo: The logo of this ShowVendorResponse.
        :type logo: str
        """
        self._logo = logo

    @property
    def name(self):
        """Gets the name of this ShowVendorResponse.

        名称

        :return: The name of this ShowVendorResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ShowVendorResponse.

        名称

        :param name: The name of this ShowVendorResponse.
        :type name: str
        """
        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowVendorResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeihealth-3.1.154-py2.py3-none-any.whl: huaweicloudsdkeihealth/v1/model/show_vendor_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowVendorResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'logo': 'str',
        'name': 'str'
    }

    attribute_map = {
        'logo': 'logo',
        'name': 'name'
    }

    def __init__(self, logo=None, name=None):
        r"""ShowVendorResponse

        The model defined in huaweicloud sdk

        :param logo: 商标Base64
        :type logo: str
        :param name: 名称
        :type name: str
        """
        
        super(ShowVendorResponse, self).__init__()

        self._logo = None
        self._name = None
        self.discriminator = None

        if logo is not None:
            self.logo = logo
        if name is not None:
            self.name = name

    @property
    def logo(self):
        r"""Gets the logo of this ShowVendorResponse.

        商标Base64

        :return: The logo of this ShowVendorResponse.
        :rtype: str
        """
        return self._logo

    @logo.setter
    def logo(self, logo):
        r"""Sets the logo of this ShowVendorResponse.

        商标Base64

        :param logo: The logo of this ShowVendorResponse.
        :type logo: str
        """
        self._logo = logo

    @property
    def name(self):
        r"""Gets the name of this ShowVendorResponse.

        名称

        :return: The name of this ShowVendorResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        r"""Sets the name of this ShowVendorResponse.

        名称

        :param name: The name of this ShowVendorResponse.
        :type name: str
        """
        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowVendorResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
